ArraySize

Enum ArraySize 

pub enum ArraySize {
    Unspecified,
    Star,
    Expr(ExprId),
}
What was written between a declarator’s brackets.

Variants



Unspecified

Nothing, as in int a[], which is an incomplete type or a parameter depending on where it is written.



Star

*, which is a variably-modified type in a prototype whose size is not named.



Expr(ExprId)

An expression, which is a constant in an ordinary array and anything at all in a VLA.