pub struct Asm {
pub template: StrId,
pub outputs: AsmOperandList,
pub inputs: AsmOperandList,
pub clobbers: StrList,
pub labels: SymbolList,
pub quals: AsmQuals,
pub span: Span,
}Expand description
An asm statement or a file-scope asm.
Fields
template: StrIdThe template, with adjacent literals already joined by phase 7.
outputs: AsmOperandListThe output operands.
inputs: AsmOperandListThe input operands, which are numbered after the outputs.
clobbers: StrListThe clobber list.
labels: SymbolListThe labels of an asm goto, and empty otherwise.
quals: AsmQualsThe qualifiers written between asm and the parenthesis.
span: SpanThe whole statement.