pub struct GenericAssoc {
pub ty: Option<TypeNameId>,
pub value: ExprId,
}Expand description
One arm of a _Generic selection.
Fields
ty: Option<TypeNameId>The type this arm matches, and None for the default arm.
value: ExprIdThe expression the arm gives, which is only evaluated if the arm is chosen.