pub struct InitItem {
pub designators: DesignatorList,
pub init: InitId,
pub span: Span,
}Expand description
One element of a braced initializer list.
Fields
designators: DesignatorListThe designators before the =, and an empty list when the element just follows the one
before it.
init: InitIdThe initializer for this element, which may itself be a braced list.
span: SpanFrom the first designator to the end of the initializer.