pub struct Printer<'a> { /* private fields */ }Expand description
A tree being written out as C.
Implementations
Sourceimpl<'a> Printer<'a>
impl<'a> Printer<'a>
Sourcepub fn new(ast: &'a Ast, names: &'a Interner) -> Printer<'a>
pub fn new(ast: &'a Ast, names: &'a Interner) -> Printer<'a>
A printer over one tree, whose names are in names.
Sourcepub fn expr(&mut self, id: ExprId)
pub fn expr(&mut self, id: ExprId)
One expression, with no parentheses around it that the grammar does not need.
Sourcepub fn type_name(&mut self, id: TypeNameId)
pub fn type_name(&mut self, id: TypeNameId)
One type name, as it would be written in a cast.