pub enum Derived {
Pointer {
quals: Quals,
attrs: AttrList,
},
Array {
size: ArraySize,
quals: Quals,
has_static: bool,
},
Function {
params: ParamList,
variadic: bool,
kind: ParamKind,
},
}Expand description
One step in a declarator, taking a type to another type.
Variants
Pointer
*, with the qualifiers that go on the pointer rather than on what it points at.
Fields
Array
[...].
Fields
Function
(...).