pub enum Scalar {
Show 29 variants
Void,
Bool,
Char,
SignedChar,
UnsignedChar,
Short,
UnsignedShort,
Int,
UnsignedInt,
Long,
UnsignedLong,
LongLong,
UnsignedLongLong,
Int128,
UnsignedInt128,
Float,
Double,
LongDouble,
Float16,
Float32,
Float64,
Float128,
Float32x,
Float64x,
Float128x,
Float80,
Decimal32,
Decimal64,
Decimal128,
}Expand description
A built-in type named by keywords, with the sign folded in.
char is here three times because plain char is a third type distinct from both
signed char and unsigned char, however it is represented on the target.
Variants
Void
void.
Bool
bool.
Char
char.
SignedChar
signed char.
UnsignedChar
unsigned char.
Short
short.
UnsignedShort
unsigned short.
Int
int.
UnsignedInt
unsigned int.
Long
long.
UnsignedLong
unsigned long.
LongLong
long long.
UnsignedLongLong
unsigned long long.
Int128
__int128.
UnsignedInt128
unsigned __int128.
Float
float.
Double
double.
LongDouble
long double.
Float16
_Float16.
Float32
_Float32.
Float64
_Float64.
Float128
_Float128.
Float32x
_Float32x.
Float64x
_Float64x.
Float128x
_Float128x.
Float80
__float80.
Decimal32
_Decimal32.
Decimal64
_Decimal64.
Decimal128
_Decimal128.